Built-in function registry, evaluation, and type system.
Re-exports
pub use aggregate::AggValueState;pub use aggregate::evaluate_aggregate;pub use registry::AggregateFunction;pub use registry::ArithmeticOp;pub use registry::ArrayOp;pub use registry::BooleanOp;pub use registry::CastTarget;pub use registry::ComparisonOp;pub use registry::DateOp;pub use registry::FunctionRegistry;pub use registry::ListOp;pub use registry::MapOp;pub use registry::ResolvedFunction;pub use registry::ScalarFunction;pub use registry::SchemaOp;pub use registry::StringOp;pub use registry::StructOp;pub use registry::TableFunction;pub use registry::UtilityOp;pub use scalar::evaluate_scalar;pub use graph::GraphDataSource;pub use graph::GraphEdge;
Modules
- aggregate
- graph
- Graph data source abstraction for table functions that need graph access.
- registry
- Function registry — manages lookup and registration of all built-in functions.
- scalar
- Scalar function evaluation.
Structs
- Data
Chunk - A contiguous batch of columnar data — the fundamental unit of data exchange between physical operators.
Enums
- Value
- A Akar value — the runtime representation of any data type.