pub struct GraphEdge {
pub src_offset: u64,
pub dst_offset: u64,
pub rel_id: u64,
pub rel_table_id: u64,
}Expand description
A directed or undirected edge in the database graph.
Fields
src_offset: u64Offset of the source node within its node table.
dst_offset: u64Offset of the destination node within its node table.
rel_id: u64Row index of the edge within its relationship table.
rel_table_id: u64ID of the relationship table that owns this edge.