pub enum TableFunction {
ScanCsv {
path: String,
},
ScanParquet {
path: String,
},
ScanJson {
path: String,
},
ListTables,
ShowColumns {
table_name: String,
},
CurrentSetting {
key: String,
},
Custom {
name: String,
},
CustomTable {
name: String,
execute: Arc<dyn Fn(&[Value], &mut DataChunk) -> Result<(), String> + Send + Sync>,
},
}Expand description
All built-in table functions.
Variants
ScanCsv
ScanParquet
ScanJson
ListTables
ShowColumns
CurrentSetting
Custom
Extension-specific custom table function (tag-based, no callback).
The name field identifies which custom function to execute.
CustomTable
Extension-provided table function with a callback closure. The closure receives input args and fills a mutable DataChunk.